GoogleAuthButton class

Inheritance

Constructors

GoogleAuthButton({required VoidCallback onPressed, Color? buttonColor, Color? splashColor, double? elevation, double borderRadius = 8.0, EdgeInsets? padding, String text = 'Sign in with Google', TextStyle? textStyle, bool darkMode = false, Color? borderColor, double? borderWidth, AuthButtonStyle? style, double? width, double? height, double iconSize = 35.0, double separator = 10.0})
GoogleAuthButton is a button for authentication with Google.

Properties

borderColor → Color?
borderColor Define the border color around the button.
final
borderRadius → double
borderRadius Define the border radius, the default value is 8.0.
final
borderWidth → double?
borderWidth Define the border width around the button.
final
buttonColor → Color?
buttonColor Define the button color. The default value is white if the darkMode = false. else the value is Color(0xff424242).
final
darkMode → bool
darkMode Define if the theme of the button is dark or light, the default value is false.
final
elevation → double?
elevation Define the elevation button, the default value is 2.0.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
height Define the height button, the default value is the minimum.
final
iconSize → double
iconSize Define the size of the icon, the default value is 35.0.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback
onPressed is a void function well be called when the button pressed.
final
padding → EdgeInsets?
padding Define the button padding, the default value is null, when the style = AuthButtonStyle.icon, the value is equal to 0.0, other way is equal to EdgeInsets.only(left: 16.0, right: 16.0, top: 6.0, bottom: 6.0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separator → double
separator Define the value of the space between the Icon and the Text. the default value is 10.0.
final
splashColor → Color?
splashColor Define the color when the button onPressed. The default value is Colors.grey.
final
style → AuthButtonStyle?
style Define the button style.
final
text → String
text Define text in the button.
final
textStyle → TextStyle?
textStyle Define the text style.
final
width → double?
width Define the button width, the default value is the minimum.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited